(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15420,        469]
NotebookOptionsPosition[     12862,        375]
NotebookOutlinePosition[     13631,        403]
CellTagsIndexPosition[     13545,        398]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.452534257633007*^9, 3.45253426980951*^9}, {
  3.502959350565922*^9, 3.50295935129818*^9}, {3.568903856148939*^9, 
  3.568903856563963*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 3.0.1 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.71216047760279*^9}],

Cell[BoxData[
 TemplateBox[{
  "ModifyBuiltIn","report",
   "\"The following built-in routines have been modified in SpinDynamica: \\!\
\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"Chop\\\", \\\",\\\", \\\"Dot\\\", \
\\\",\\\", \\\"Duration\\\", \\\",\\\", \\\"Exp\\\", \\\",\\\", \
\\\"Expand\\\", \\\",\\\", \\\"ExpandAll\\\", \\\",\\\", \\\"NumericQ\\\", \\\
\",\\\", \\\"Plus\\\", \\\",\\\", \\\"Power\\\", \\\",\\\", \\\"Simplify\\\", \
\\\",\\\", \\\"Times\\\", \\\",\\\", \\\"WignerD\\\"}], \\\"}\\\"}]\\). \
\\nEvaluate \
??\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\) to \
generate the additional definitions for \
\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\).\"",2,1,
   1,29119467868261672109,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.712160479004787*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AxesToEuler"}]], "Input",
 CellChangeTimes->{{3.502951122401466*^9, 3.5029511238427877`*^9}, 
   3.502959366876554*^9}],

Cell[BoxData[
 StyleBox["\<\"AxesToEuler[system2,system1,opts] gives the Euler angles \
\[CapitalOmega]21={\[Alpha]21,\[Beta]21,\[Gamma]21} by which each axis of \
system2 may be rotated around the system1 axes in order to be brought into \
coincide with the corresponding axis of system1:\\n\t\t\
e\[Micro]1=Rz1(\[Alpha]21)Ry1(\[Beta]21)Rz1(\[Gamma]21).e\[Micro]2, where \
\[Mu]\[Element]{x,y,z}.\\nThe same result is generated by rotating around the \
system2 axes:\\n\t\te\[Micro]1=Rz2(\[Alpha]21)Ry2(\[Beta]21)Rz2(\[Gamma]21).e\
\[Micro]2, where \[Mu]\[Element]{x,y,z}.\\nThe same result is also generated \
by using \\\"moving axes\\\", where the axes follow the Euler rotations, but \
in this case the angles are applied in reverse order:\\n\t\te\[Micro]1=Rz2'(\
\[Gamma]21)Ry2'(\[Beta]21)Rz2(\[Alpha]21).e\[Micro]2, \\nwhere the primed \
axes of system1 follow the rotation.  \\n\\nIn a typical application, system2 \
is the principal axis system P of an anisotropic interaction, and system1 is \
a reference axis system such as a molecular frame M, or the laboratory frame \
L. The routine AxesToEuler[P,M] then generates the Euler angles \
\[CapitalOmega]PM which would be used in spherical tensor realisations of the \
spin Hamiltonian. \\n\\nEach of system1 and system2 may have the form {Z} or \
{X,Z} or {X,Y,Z}. Here Z,X and Y are 3-vectors. If only Z is specified, the \
two remaining axes are constructed. If X and Z is specified, the z-axis of \
the constructed system is equal to Z and the x-axis is in the XZ plane. If \
all three axes are specified, they must be a right-handed orthogonal \
set.\\nIf system1 is missing, the system {ex,ey,ez} is \
assumed.\\n\\nAxesToEuler also accepts axis definitions containing symbolic \
angles; in this case the symbolic result assumes that all angles are in the \
first quadrant (i.e. greater than 0 and less than \[Pi]/2).\\n\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.712160479469618*^9},
 CellTags->"Info23712164079-9490620"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
generate a randomly oriented Axis system (specifying the z-axis)\
\>", "Subsubsection",
 CellChangeTimes->{{3.502959496293704*^9, 3.502959502644566*^9}, {
  3.502959578047159*^9, 3.5029595817565527`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vecz", "=", 
  RowBox[{"RandomReal", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", "3", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.502959394854488*^9, 3.502959404414001*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.39458137823109496`", ",", 
   RowBox[{"-", "0.15952689582481527`"}], ",", 
   RowBox[{"-", "0.41232308840910203`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5029594048354883`*^9, 3.515084106760778*^9, 
  3.5689037866229625`*^9, 3.71216047949914*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"axes", "=", 
  RowBox[{"AxisSystem", "[", "vecz", "]"}]}]], "Input",
 CellChangeTimes->{{3.5029594073093157`*^9, 3.5029594104174356`*^9}, {
  3.502959446016757*^9, 3.502959451462463*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.7460697584475311`", ",", "0.2402668800465513`", ",", 
     "0.621008648798661`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "0.9326305565234166`"}], ",", "0.3608327105998323`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6658677913295121`", ",", 
     RowBox[{"-", "0.26920637323718477`"}], ",", 
     RowBox[{"-", "0.6958074540262119`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.502959452029929*^9, 3.515084106814973*^9, 
  3.568903793294344*^9, 3.7121604795196557`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
derive the Euler angles relating the axis system to the original frame\
\>", "Subsubsection",
 CellChangeTimes->{{3.502959496293704*^9, 3.502959528084179*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}], "=", 
  RowBox[{"AxesToEuler", "[", "axes", "]"}]}]], "Input",
 CellChangeTimes->{{3.50295945728442*^9, 3.502959472205863*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.526363873885904`", ",", "2.3403398464860476`", ",", 
   RowBox[{"-", "2.757390015828537`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.502959461690503*^9, 3.5029594730581636`*^9}, 
   3.515084106865643*^9, 3.5689038020398445`*^9, 3.712160479546173*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}], "/", 
  "\[Degree]"}]], "Input",
 CellChangeTimes->{{3.502959478439288*^9, 3.502959481053616*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30.158428461818627`", ",", "134.0915958299455`", ",", 
   RowBox[{"-", "157.98681037848644`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5029594817625637`*^9, 3.515084106918662*^9, 
  3.568903807050131*^9, 3.7121604795596848`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["rotate the axis system back to the original position", "Subsubsection",
 CellChangeTimes->{{3.502959496293704*^9, 3.502959543068143*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "@", 
  RowBox[{"RotateEuler", "[", 
   RowBox[{"axes", ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.50295945728442*^9, 3.502959472205863*^9}, {
  3.502959545437793*^9, 3.502959559333898*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.0000000000000002`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.502959461690503*^9, 3.5029594730581636`*^9}, {
   3.5029595558623667`*^9, 3.502959559728403*^9}, 3.5150841069613943`*^9, 
   3.5689038136165066`*^9, 3.7121604795751925`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
generate a randomly oriented Axis system (specifying two axes)\
\>", "Subsubsection",
 CellChangeTimes->{{3.502959496293704*^9, 3.502959502644566*^9}, {
  3.502959578047159*^9, 3.502959597284326*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"vecx", "=", 
  RowBox[{"RandomReal", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", "3", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"vecz", "=", 
  RowBox[{"RandomReal", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", "3", "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.502959394854488*^9, 3.502959404414001*^9}, {
  3.502959601857892*^9, 3.5029596062668552`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.007059916359646756`", ",", 
   RowBox[{"-", "0.2899237151638028`"}], ",", 
   RowBox[{"-", "0.9261570593394732`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5029594048354883`*^9, 3.502959608012648*^9, 
  3.515084107028289*^9, 3.5689038213829503`*^9, 3.7121604795882025`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.6417690855257456`"}], ",", "0.030190489676862775`", ",", 
   RowBox[{"-", "0.02734664841705481`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5029594048354883`*^9, 3.502959608012648*^9, 
  3.515084107028289*^9, 3.5689038213829503`*^9, 3.7121604795907035`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"axes", "=", 
  RowBox[{"AxisSystem", "[", 
   RowBox[{"vecx", ",", "vecz"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5029594073093157`*^9, 3.5029594104174356`*^9}, {
  3.502959446016757*^9, 3.502959451462463*^9}, {3.502959611855496*^9, 
  3.502959613750083*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.026538384992843295`", ",", 
     RowBox[{"-", "0.2996978827384916`"}], ",", 
     RowBox[{"-", "0.9536649795415771`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.057517671800767584`"}], ",", 
     RowBox[{"-", "0.9528782987481813`"}], ",", "0.2978500716894169`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9979916991401236`"}], ",", "0.04694812942851846`", ",", 
     RowBox[{"-", "0.04252577560224229`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.502959452029929*^9, 3.502959614558528*^9, 
  3.515084107130299*^9, 3.5689038259382114`*^9, 3.712160479605715*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
derive the Euler angles relating the axis system to the original frame\
\>", "Subsubsection",
 CellChangeTimes->{{3.502959496293704*^9, 3.502959528084179*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}], "=", 
  RowBox[{"AxesToEuler", "[", "axes", "]"}]}]], "Input",
 CellChangeTimes->{{3.50295945728442*^9, 3.502959472205863*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.838870417680651`", ",", "1.6133349304028428`", ",", 
   "0.04700794927068053`"}], "}"}]], "Output",
 CellChangeTimes->{{3.502959461690503*^9, 3.5029594730581636`*^9}, 
   3.5029596179393663`*^9, 3.51508410719733*^9, 3.568903832522588*^9, 
   3.7121604796262293`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}], "/", 
  "\[Degree]"}]], "Input",
 CellChangeTimes->{{3.502959478439288*^9, 3.502959481053616*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "162.6552935176425`", ",", "92.4372824531153`", ",", 
   "2.6933570967750704`"}], "}"}]], "Output",
 CellChangeTimes->{3.5029594817625637`*^9, 3.502959620386984*^9, 
  3.515084107262409*^9, 3.5689038363638077`*^9, 3.7121604796502466`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["rotate the axis system back to the original position", "Subsubsection",
 CellChangeTimes->{{3.502959496293704*^9, 3.502959543068143*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "@", 
  RowBox[{"RotateEuler", "[", 
   RowBox[{"axes", ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.50295945728442*^9, 3.502959472205863*^9}, {
  3.502959545437793*^9, 3.502959559333898*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9999999999999999`", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.0000000000000002`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.502959461690503*^9, 3.5029594730581636`*^9}, {
   3.5029595558623667`*^9, 3.502959559728403*^9}, 3.5029596230613947`*^9, 
   3.515084107327426*^9, 3.56890384200413*^9, 3.712160479664256*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.98}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info23712164079-9490620"->{
  Cell[1983, 59, 2007, 28, 321, "Print",
   CellTags->"Info23712164079-9490620"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info23712164079-9490620", 13439, 392}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 240, 4, 30, "Input"],
Cell[810, 28, 146, 4, 36, "Print"],
Cell[959, 34, 836, 15, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1832, 54, 148, 3, 30, "Input"],
Cell[1983, 59, 2007, 28, 321, "Print",
 CellTags->"Info23712164079-9490620"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4027, 92, 214, 4, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[4266, 100, 277, 8, 30, "Input"],
Cell[4546, 110, 292, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4875, 121, 211, 4, 30, "Input"],
Cell[5089, 127, 598, 16, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5736, 149, 169, 3, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[5930, 156, 232, 5, 30, "Input"],
Cell[6165, 163, 294, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6496, 173, 203, 5, 30, "Input"],
Cell[6702, 180, 270, 5, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7021, 191, 143, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[7189, 196, 316, 8, 30, "Input"],
Cell[7508, 206, 478, 11, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8035, 223, 210, 4, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[8270, 231, 542, 16, 50, "Input"],
Cell[8815, 249, 316, 6, 30, "Output"],
Cell[9134, 257, 317, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9488, 268, 287, 6, 30, "Input"],
Cell[9778, 276, 694, 17, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10521, 299, 169, 3, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[10715, 306, 232, 5, 30, "Input"],
Cell[10950, 313, 311, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11298, 325, 203, 5, 30, "Input"],
Cell[11504, 332, 280, 6, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11833, 344, 143, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[12001, 349, 316, 8, 30, "Input"],
Cell[12320, 359, 514, 12, 30, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

